@@ -1,7 +1,5 @@
-/* $Id: data.c,v 1.36 2008/01/30 12:06:49 dijkstra Exp $ */
-
 /*
- * Copyright (c) 2001-2008 Willem Dijkstra
+ * Copyright (c) 2001-2024 Willem Dijkstra
  * All rights reserved.
  *
  * The crc routine is by Rob Warnock <rpw3@sgi.com>, from the
@@ -89,7 +87,7 @@ struct {
     { 'l', ":%lu", " %10lu", 12, sizeof(u_int32_t), (u_int64_t) 0xffffffff },
     { 's', ":%u", " %5u", 7, sizeof(u_int16_t), (u_int64_t) 0xffff },
     { 'c', ":%3.2f", " %3.2f", 8, sizeof(u_int16_t), (u_int64_t) 100 },
-    { 'b', ":%3u", " %3u", 5, sizeof(u_int8_t), (u_int64_t) 255 },
+    { 'b', ":%u", " %3u", 5, sizeof(u_int8_t), (u_int64_t) 255 },
     { '\0', NULL, NULL, 0, 0, 0 }
 };
 /* streams of <type> have the packedstream <form> */
@@ -112,6 +110,9 @@ struct {
     { MT_MEM2, "LLLLL" },
     { MT_IF2, "LLLLLLLLLL" },
     { MT_CPUIOW, "cccccc" },
+    { MT_SMART, "bbbbbbbbbbbb" },
+    { MT_LOAD, "ccc" },
+    { MT_FLUKSO, "D" },
     { MT_TEST, "LLLLDDDDllllssssccccbbbb" },
     { MT_EOT, "" }
 };
@@ -135,6 +136,9 @@ struct {
     { MT_MEM2, LXT_MEM },
     { MT_IF2, LXT_IF },
     { MT_CPUIOW, LXT_CPUIOW },
+    { MT_SMART, LXT_SMART },
+    { MT_LOAD, LXT_LOAD },
+    { MT_FLUKSO, LXT_FLUKSO },
     { MT_EOT, LXT_BADTOKEN }
 };
 /* parallel crc32 table */
@@ -361,7 +365,7 @@ snpackx(size_t maxarglen, char *buf, int maxlen, char *id, int type, va_list ap)
     int offset = 0;
     int arglen = 0;
 
-    if (type > MT_EOT) {
+    if (type < 0 || type >= MT_EOT) {
         warning("stream type (%d) out of range", type);
         return 0;
     }
@@ -457,7 +461,9 @@ snpackx(size_t maxarglen, char *buf, int maxlen, char *id, int type, va_list ap)
  * Note that this function does "automatic" bounds checking; it uses a
  * description of the packedstream (streamform) to parse the actual bytes. This
  * description corresponds to the amount of bytes that will fit inside the
- * packedstream structure.  */
+ * packedstream structure.
+ * TODO do more explicit bounds checking
+ */
 int
 sunpack(char *buf, struct packedstream *ps)
 {
@@ -490,8 +496,8 @@ sunpackx(size_t arglen, char *buf, struct packedstream *ps)
 
     in = buf;
 
-    if ((*in) > MT_EOT) {
-        warning("unpack failure: stream type (%d) out of range", (*in));
+    if (*in < 0 || *in >= MT_EOT) {
+        warning("unpack failure: stream type (%d) out of range", *in);
         return -1;
     }
 
@@ -605,6 +611,7 @@ ps2strn(struct packedstream * ps, char *buf, const int maxlen, int pretty)
         switch (vartype) {
         case 'b':
             bcopy(in, &b, sizeof(u_int8_t));
+            b &= 0xff;
             snprintf(out, strlenvar(vartype), formatstr, b);
             in++;
             break;
@@ -1057,7 +1064,7 @@ crc32(const void *buf, unsigned int len)
 }
 /* Init table for CRC32 */
 void
-init_crc32()
+init_crc32(void)
 {
     unsigned int i, j;
     u_int32_t c;
@@ -1069,3 +1076,15 @@ init_crc32()
         crc32_table[i] = c;
     }
 }
+int
+gcd(int a, int b)
+{
+    for(;;) {
+        if (a == 0)
+            return b;
+        b %= a;
+        if (b == 0)
+            return a;
+        a %= b;
+    }
+}
