@@ -1,7 +1,5 @@
-/* $Id: data.h,v 1.33 2008/01/30 12:06:49 dijkstra Exp $ */
-
 /*
- * Copyright (c) 2001-2008 Willem Dijkstra
+ * Copyright (c) 2001-2024 Willem Dijkstra
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -129,6 +127,8 @@ struct mux {
     int clientsocket;           /* symux; incoming tcp connections */
     int symonsocket[AF_MAX];    /* symux; incoming symon data */
     int symuxsocket;            /* symon; outgoing data to mux */
+    int last;
+    int interval;
     struct symonpacket packet;
     struct sockaddr_storage sockaddr;
     struct streamlist sl;
@@ -143,8 +143,8 @@ SLIST_HEAD(muxlist, mux);
 
 /* Stream types
  *
- * Add new items at the bottom to preserve compatibility with older symon
- * instances
+ * Add new items at the bottom, before entries for test and eot to preserve
+ * compatibility with older symon instances
  */
 #define MT_IO1    0
 #define MT_CPU    1
@@ -161,8 +161,11 @@ SLIST_HEAD(muxlist, mux);
 #define MT_MEM2   12
 #define MT_IF2    13
 #define MT_CPUIOW 14
-#define MT_TEST   15
-#define MT_EOT    16
+#define MT_SMART  15
+#define MT_LOAD   16
+#define MT_FLUKSO 17
+#define MT_TEST   18
+#define MT_EOT    19
 
 /*
  * Unpacking of incoming packets is done via a packedstream structure. This
@@ -329,6 +332,28 @@ struct packedstream {
             u_int16_t midle;
             u_int16_t miowait;
         }      ps_cpuiow;
+        struct {
+            u_int8_t read_error_rate;
+            u_int8_t reallocated_sectors;
+            u_int8_t spin_retries;
+            u_int8_t air_flow_temp;
+            u_int8_t temperature;
+            u_int8_t reallocations;
+            u_int8_t current_pending;
+            u_int8_t uncorrectables;
+            u_int8_t soft_read_error_rate;
+            u_int8_t g_sense_error_rate;
+            u_int8_t temperature2;
+            u_int8_t free_fall_protection;
+        }      ps_smart;
+        struct {
+            u_int16_t mload1;
+            u_int16_t mload2;
+            u_int16_t mload3;
+        }      ps_load;
+        struct {
+            int64_t value;
+        }      ps_flukso;
     }     data;
 };
 
@@ -337,6 +362,7 @@ __BEGIN_DECLS
 char *type2str(const int);
 int bytelen_sourcelist(struct sourcelist *);
 int bytelen_streamlist(struct streamlist *);
+int gcd(int a, int b);
 int getheader(char *, struct symonpacketheader *);
 int ps2strn(struct packedstream *, char *, int, int);
 int setheader(char *, struct symonpacketheader *);
@@ -364,7 +390,7 @@ u_int32_t crc32(const void *, unsigned int);
 void free_muxlist(struct muxlist *);
 void free_sourcelist(struct sourcelist *);
 void free_streamlist(struct streamlist *);
-void init_crc32();
+void init_crc32(void);
 void init_symon_packet(struct mux *);
 void init_symux_packet(struct mux *);
 __END_DECLS
