@@ -1,5 +1,3 @@
-/* $Id: platform.h,v 1.6 2007/02/11 20:07:31 dijkstra Exp $ */
-
 #ifndef _CONF_FREEBSD_H
 #define _CONF_FREEBSD_H
 
@@ -8,6 +6,7 @@
 #include <sys/socket.h>
 #include <sys/time.h>
 #include <sys/dkstat.h>
+#include <sys/param.h>
 #include <sys/resource.h>
 
 #include <net/if.h>
@@ -20,18 +19,23 @@
 #define SA_LEN(x)       ((x)->sa_len)
 #define SS_LEN(x)       ((x)->ss_len)
 
+#define DISK_PATHS { "%s", "/dev/%s", "/dev/ufs/%s", "/dev/ufsid/%s", "/dev/gpt/%s", "/dev/label/%s", NULL }
+#define MAX_PATH_LEN MAXPATHLEN
+
 union stream_parg {
     struct {
-        long time[CPUSTATES];
-        long old[CPUSTATES];
-        long diff[CPUSTATES];
-        int states[CPUSTATES];
+        int64_t time2[CPUSTATES];
+        int64_t old[CPUSTATES];
+        int64_t diff[CPUSTATES];
+        int64_t states[CPUSTATES];
+        uint8_t id;
     } cp;
     struct {
         char rawdev[SYMON_DFNAMESIZE];
     } df;
     struct ifreq ifr;
     int sn;
+    int smart;
 };
 
 #endif
