@@ -1,7 +1,6 @@
-/* $Id: sm_df.c,v 1.1 2007/02/11 20:08:19 dijkstra Exp $ */
-
 /*
  * Copyright (c) 2005 Marc Balmer
+ * Copyright (c) 2012-2024 Willem Dijkstra
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -54,6 +53,7 @@
 
 #include "error.h"
 #include "symon.h"
+#include "diskname.h"
 
 /* Globals for this module start with df_ */
 static struct statfs *df_stats = NULL;
@@ -62,14 +62,32 @@ static int df_parts = 0;
 void
 init_df(struct stream *st)
 {
-    strlcpy(st->parg.df.rawdev, "/dev/", sizeof(st->parg.df.rawdev));
-    strlcat(st->parg.df.rawdev, st->arg, sizeof(st->parg.df.rawdev));
+    struct disknamectx c;
+    int n;
+    char drivename[SYMON_DFNAMESIZE];
 
-    info("started module df(%.200s)", st->arg);
+    if (st->arg == NULL)
+        fatal("df: need a <disk device|name> argument");
+
+    initdisknamectx(&c, st->arg, drivename, sizeof(drivename));
+
+    gets_df();
+
+    while (nextdiskname(&c)) {
+        for (n = 0; n < df_parts; n++) {
+            if (!strncmp(df_stats[n].f_mntfromname, drivename, SYMON_DFNAMESIZE)) {
+                strlcpy(st->parg.df.rawdev, drivename, sizeof(st->parg.df.rawdev));
+                info("started module df(%.200s)", st->arg);
+                return;
+            }
+        }
+    }
+
+    warning("df(%.200s) failed (no such device)", st->arg);
 }
 
 void
-gets_df()
+gets_df(void)
 {
     if ((df_parts = getmntinfo(&df_stats, MNT_NOWAIT)) == 0) {
         warning("df failed");
