@@ -1,8 +1,6 @@
-/* $Id: sm_mem.c,v 1.14 2008/03/21 13:22:03 dijkstra Exp $ */
-
 /*
  * Copyright (c) 2004      Matthew Gream
- * Copyright (c) 2001-2008 Willem Dijkstra
+ * Copyright (c) 2001-2024 Willem Dijkstra
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -110,15 +108,15 @@ init_mem(struct stream *st)
 }
 
 void
-gets_mem()
+gets_mem(void)
 {
 #ifdef HAS_XSWDEV
-    int i;
     u_int vmnswp_dat;
-    size_t vmnswp_siz;
+    u_long vmnswp_siz;
+    u_int i;
 #endif
     u_long physmem_dat;
-    size_t physmem_siz;
+    u_long physmem_siz;
 
     bzero(&me_vmtotal, sizeof(me_vmtotal));
 
