@@ -1,7 +1,5 @@
-/* $Id: sm_io.c,v 1.3 2008/04/06 13:02:12 dijkstra Exp $ */
-
 /*
- * Copyright (c) 2001-2006 Willem Dijkstra
+ * Copyright (c) 2001-2024 Willem Dijkstra
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -37,24 +35,28 @@
  *
  */
 
+#include "conf.h"
+
 #include <sys/param.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 
 #include <errno.h>
 #include <fcntl.h>
+#include <inttypes.h>
 #include <string.h>
 #include <unistd.h>
 
-#include "conf.h"
 #include "xmalloc.h"
 #include "error.h"
 #include "symon.h"
+#include "diskname.h"
 
 /* Globals for this module start with io_ */
 static void *io_buf = NULL;
 static int io_size = 0;
 static int io_maxsize = 0;
+static int io_fd = -1;
 struct io_device_stats
 {
     u_int64_t read_issued;
@@ -81,26 +83,60 @@ char *io_filename = "/proc/partitions";
 void
 init_io(struct stream *st)
 {
+    struct disknamectx c;
+    size_t lead = sizeof("/dev/") - 1;
+
     if (io_buf == NULL) {
         io_maxsize = SYMON_MAX_OBJSIZE;
         io_buf = xmalloc(io_maxsize);
     }
 
-    info("started module io(%.200s)", st->arg);
+    if (st->arg == NULL)
+        fatal("io: need a <device>|<devicename> argument");
+
+    if ((io_fd = open(io_filename, O_RDONLY)) < 0)
+        warning("cannot access %.200s: %.200s", io_filename, strerror(errno));
+
+    /* Retrieve io stats to search for devicename */
+    gets_io();
+
+    initdisknamectx(&c, st->arg, st->parg.io, sizeof(st->parg.io));
+
+    while (nextdiskname(&c) != NULL) {
+        /* devices are named sdX, not /dev/sdX */
+        if (strncmp(st->parg.io, "/dev/", lead) == 0)
+            memmove(&st->parg.io[0], &st->parg.io[0] + lead, sizeof(st->parg.io) - lead);
+
+        if (strstr(io_buf, st->parg.io)) {
+            if (strcmp(st->arg, st->parg.io) == 0)
+                info("started module io(%.200s)", st->parg.io);
+            else
+                info("started module io(%.200s = %.200s)", st->arg, st->parg.io);
+            return;
+        }
+    }
+
+    warning("io(%.200s): not mounted", st->arg);
 }
 
 void
-gets_io()
+gets_io(void)
 {
-    int fd;
-    if ((fd = open(io_filename, O_RDONLY)) < 0) {
-        warning("cannot access %.200s: %.200s", io_filename, strerror(errno));
-        return;
-    }
+    int len;
+    char *p;
+
+    if (lseek(io_fd, 0, SEEK_SET) != 0)
+        fatal("%s seek error: %.200s", io_filename, strerror(errno));
 
     bzero(io_buf, io_maxsize);
-    io_size = read(fd, io_buf, io_maxsize);
-    close(fd);
+
+    len = 0;
+    p = io_buf;
+    io_size = 0;
+    while ((len = read(io_fd, p, io_maxsize - io_size)) > 0) {
+      p += len;
+      io_size += len;
+    }
 
     if (io_size == io_maxsize) {
         /* buffer is too small to hold all interface data */
@@ -129,15 +165,20 @@ get_io(char *symon_buf, int maxlen, struct stream *st)
         return 0;
     }
 
-    if ((line = strstr(io_buf, st->arg)) == NULL) {
-        warning("could not find disk %s", st->arg);
+    if ((line = strstr(io_buf, st->parg.io)) == NULL) {
+        warning("could not find disk %.200s = %.200s", st->arg, st->parg.io);
         return 0;
     }
 
-    line += strlen(st->arg);
+    line += strlen(st->parg.io);
     bzero(&stats, sizeof(struct io_device_stats));
 
-    if (11 > sscanf(line, " %llu %llu %llu %llu %llu %llu %llu %llu %llu %llu %llu\n",
+    if (11 > sscanf(line, " %" SCNu64 " %" SCNu64
+                          " %" SCNu64 " %" SCNu64
+                          " %" SCNu64 " %" SCNu64
+                          " %" SCNu64 " %" SCNu64
+                          " %" SCNu64 " %" SCNu64
+                          " %" SCNu64 "\n",
                     &stats.read_issued, &stats.read_merged,
                     &stats.read_sectors, &stats.read_milliseconds,
                     &stats.write_issued, &stats.write_merged,
@@ -145,7 +186,8 @@ get_io(char *symon_buf, int maxlen, struct stream *st)
                     &stats.progress_ios, &stats.progress_milliseconds,
                     &stats.progress_weight)) {
 #ifdef HAS_PROC_DISKSTATS
-        if (4 > sscanf(line, " %llu %llu %llu %llu\n",
+        if (4 > sscanf(line, " %" SCNu64 " %" SCNu64
+                             " %" SCNu64 " %" SCNu64 "\n",
                        &stats.read_issued, &stats.read_sectors,
                        &stats.write_issued, &stats.write_sectors)) {
             warning("could not parse disk statistics for %.200s", st->arg);
@@ -172,7 +214,7 @@ init_io(struct stream *st)
     fatal("io module not available");
 }
 void
-gets_io()
+gets_io(void)
 {
     fatal("io module not available");
 }
