@@ -1,5 +1,3 @@
-/* $Id: platform.h,v 1.6 2007/07/05 13:14:05 dijkstra Exp $ */
-
 #ifndef _CONF_NETBSD_H
 #define _CONF_NETBSD_H
 
@@ -8,9 +6,12 @@
 #include <sys/queue.h>
 #include <sys/sched.h>
 #include <sys/types.h>
+#include <sys/param.h>
 
 #include <net/if.h>
 
+#include <stdio.h>
+
 #include "sylimits.h"
 
 #define SYMON_USER      "_symon"
@@ -22,18 +23,21 @@ union semun {
         int val;
 };
 
+#define MAX_PATH_LEN MAXPATHLEN
+
 union stream_parg {
     struct {
-        u_int64_t time[CPUSTATES];
-        u_int64_t old[CPUSTATES];
-        u_int64_t diff[CPUSTATES];
-        int states[CPUSTATES];
+        int64_t time[CPUSTATES];
+        int64_t old[CPUSTATES];
+        int64_t diff[CPUSTATES];
+        int64_t states[CPUSTATES];
     } cp;
     struct {
         char rawdev[SYMON_DFNAMESIZE];
     } df;
     struct ifdatareq ifr;
     int sn;
+    int smart;
 };
 
 #endif
