@@ -1,7 +1,5 @@
-/* $Id: sm_io.c,v 1.5 2007/07/05 13:33:26 dijkstra Exp $ */
-
 /*
- * Copyright (c) 2007      Willem Dijkstra
+ * Copyright (c) 2007-2024 Willem Dijkstra
  * Copyright (c) 2004      Matthew Gream
  * All rights reserved.
  *
@@ -63,7 +61,7 @@ static int io_maxdks = 0;
 #ifndef HAS_HW_IOSTATS
 static struct disk_sysctl *io_dkstats = NULL;
 void
-gets_io()
+gets_io(void)
 {
     int mib[3];
     size_t size;
@@ -101,7 +99,7 @@ gets_io()
 #else
 static struct io_sysctl *io_dkstats = NULL;
 void
-gets_io()
+gets_io(void)
 {
     int mib[3];
     size_t size;
