@@ -1,8 +1,6 @@
-/* $Id: sm_proc.c,v 1.6 2008/02/20 08:17:25 dijkstra Exp $ */
-
 /*
  * Copyright (c) 2004      Matthew Gream
- * Copyright (c) 2001-2008 Willem Dijkstra
+ * Copyright (c) 2001-2024 Willem Dijkstra
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -38,6 +36,8 @@
  * cpuseconds : procsizes : resident segment sizes
  */
 
+#define _KMEMUSER 1
+
 #include <sys/param.h>
 #include <sys/sysctl.h>
 
@@ -65,7 +65,7 @@ typedef long pctcpu;
 #define pctdouble(p) ((double)(p) / FIXED_PCTCPU)
 
 void
-gets_proc()
+gets_proc(void)
 {
     int mib[3];
     int procs;
@@ -114,7 +114,7 @@ gets_proc()
 }
 
 void
-privinit_proc()
+privinit_proc(void)
 {
     /* EMPTY */
 }
