@@ -1,14 +1,15 @@
-/* $Id: platform.h,v 1.8 2007/05/12 16:46:27 dijkstra Exp $ */
-
 #ifndef _CONF_OPENBSD_H
 #define _CONF_OPENBSD_H
 
 #include "conf.h"
 
-#include <sys/dkstat.h>
 #include <sys/queue.h>
 #include <sys/types.h>
+#include <sys/select.h> /* fd_set */
 #include <sys/socket.h>
+#include <sys/sched.h>
+#include <sys/syslimits.h>
+#include <time.h>
 #include <net/if.h>
 
 #include "sylimits.h"
@@ -18,6 +19,8 @@
 #define SA_LEN(x)       ((x)->sa_len)
 #define SS_LEN(x)       ((x)->ss_len)
 
+#define MAX_PATH_LEN PATH_MAX
+
 union stream_parg {
     struct {
         long time1[CPUSTATES];
@@ -33,12 +36,9 @@ union stream_parg {
     } df;
     struct ifreq ifr;
     struct {
-#ifndef HAS_SENSORDEV
-        int mib[3];
-#else
         int mib[5];
-#endif
     } sn;
+    int smart;
 };
 
 #endif
