@@ -1,5 +1,3 @@
-/* $Id: sm_df.c,v 1.4 2007/02/11 20:07:32 dijkstra Exp $ */
-
 /*
  * Copyright (c) 2005 Marc Balmer
  * All rights reserved.
@@ -69,7 +67,7 @@ init_df(struct stream *st)
 }
 
 void
-gets_df()
+gets_df(void)
 {
     if ((df_parts = getmntinfo(&df_stats, MNT_NOWAIT)) == 0) {
         warning("df failed");
