@@ -1,7 +1,5 @@
-/* $Id: sm_proc.c,v 1.9 2008/02/20 08:17:25 dijkstra Exp $ */
-
 /*
- * Copyright (c) 2001-2008 Willem Dijkstra
+ * Copyright (c) 2001-2024 Willem Dijkstra
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -38,6 +36,8 @@
  *
  */
 
+#include "conf.h"
+
 #include <sys/param.h>
 #include <sys/sysctl.h>
 
@@ -64,10 +64,11 @@ static int proc_pagesize;
 typedef long pctcpu;
 #define pctdouble(p) ((double)(p) / FIXED_PCTCPU)
 
+
 void
-gets_proc()
+gets_proc(void)
 {
-    int mib[3];
+    int mib[6];
     int procs;
     size_t size;
 
@@ -96,8 +97,11 @@ gets_proc()
     mib[0] = CTL_KERN;
     mib[1] = KERN_PROC;
     mib[2] = KERN_PROC_KTHREAD;
+    mib[3] = 0;
+    mib[4] = sizeof(struct kinfo_proc);
+    mib[5] = proc_max;
     size = proc_max * sizeof(struct kinfo_proc);
-    if (sysctl(mib, 3, proc_ps, &size, NULL, 0) < 0) {
+    if (sysctl(mib, 6, proc_ps, &size, NULL, 0) < 0) {
         warning("proc probe cannot get processes");
         proc_cur = 0;
         return;
@@ -113,7 +117,7 @@ gets_proc()
 }
 
 void
-privinit_proc()
+privinit_proc(void)
 {
     /* EMPTY */
 }
@@ -160,19 +164,19 @@ get_proc(char *symon_buf, int maxlen, struct stream *st)
     int n = 0;
 
     for (pp = proc_ps, i = 0; i < proc_cur; pp++, i++) {
-         if (strncmp(st->arg, pp->kp_proc.p_comm, strlen(st->arg)) == 0) {
+         if (strncmp(st->arg, pp->p_comm, strlen(st->arg)) == 0) {
              /* cpu time - accumulated */
-             cpu_uticks += pp->kp_proc.p_uticks;  /* user */
-             cpu_sticks += pp->kp_proc.p_sticks;  /* sys  */
-             cpu_iticks += pp->kp_proc.p_iticks;  /* int  */
+             cpu_uticks += pp->p_uticks;  /* user */
+             cpu_sticks += pp->p_sticks;  /* sys  */
+             cpu_iticks += pp->p_iticks;  /* int  */
              /* cpu time - percentage since last measurement */
-             cpu_pct = pctdouble(pp->kp_proc.p_pctcpu) * 100.0;
+             cpu_pct = pctdouble(pp->p_pctcpu) * 100.0;
              cpu_pcti += cpu_pct;
              /* memory size - shared pages are counted multiple times */
-             mem_procsize += pagetob(pp->kp_eproc.e_vm.vm_tsize + /* text pages */
-                                     pp->kp_eproc.e_vm.vm_dsize + /* data */
-                                     pp->kp_eproc.e_vm.vm_ssize); /* stack */
-             mem_rss += pagetob(pp->kp_eproc.e_vm.vm_rssize);     /* rss  */
+             mem_procsize += pagetob(pp->p_vm_tsize + /* text pages */
+                                     pp->p_vm_dsize + /* data */
+                                     pp->p_vm_ssize); /* stack */
+             mem_rss += pagetob(pp->p_vm_rssize);     /* rss  */
              n++;
          }
     }
