@@ -1,5 +1,3 @@
-/* $Id: sm_cpu.c,v 1.3 2005/10/18 19:58:12 dijkstra Exp $ */
-
 #include <stdlib.h>
 
 #include "sylimits.h"
@@ -12,7 +10,7 @@ init_cpu(struct stream *st)
     fatal("cpu module not available");
 }
 void
-gets_cpu()
+gets_cpu(void)
 {
     fatal("cpu module not available");
 }
