@@ -1,5 +1,3 @@
-/* $Id: sm_io.c,v 1.2 2005/10/18 19:58:12 dijkstra Exp $ */
-
 #include <stdlib.h>
 
 #include "sylimits.h"
@@ -12,7 +10,7 @@ init_io(struct stream *st)
     fatal("io module not available");
 }
 void
-gets_io()
+gets_io(void)
 {
     fatal("io module not available");
 }
