@@ -1,5 +1,3 @@
-/* $Id: sm_mem.c,v 1.3 2005/10/18 19:58:12 dijkstra Exp $ */
-
 #include <stdlib.h>
 
 #include "sylimits.h"
@@ -12,7 +10,7 @@ init_mem(struct stream *st)
     fatal("mem module not available");
 }
 void
-gets_mem()
+gets_mem(void)
 {
     fatal("mem module not available");
 }
