@@ -1,5 +1,3 @@
-/* $Id: sm_pf.c,v 1.2 2005/10/18 19:58:12 dijkstra Exp $ */
-
 #include <stdlib.h>
 
 #include "sylimits.h"
@@ -7,7 +5,7 @@
 #include "error.h"
 
 void
-privinit_pf()
+privinit_pf(void)
 {
     fatal("pf module not available");
 }
@@ -17,7 +15,7 @@ init_pf(struct stream *st)
     fatal("pf module not available");
 }
 void
-gets_pf()
+gets_pf(void)
 {
     fatal("pf module not available");
 }
