@@ -1,5 +1,3 @@
-/* $Id: sm_sensor.c,v 1.2 2005/10/18 19:58:12 dijkstra Exp $ */
-
 #include <stdlib.h>
 
 #include "sylimits.h"
@@ -7,7 +5,7 @@
 #include "error.h"
 
 void
-privinit_sensor()
+privinit_sensor(void)
 {
     fatal("sensor module not available");
 }
