@@ -1,7 +1,5 @@
-/* $Id: readconf.c,v 1.29 2008/01/30 12:06:50 dijkstra Exp $ */
-
 /*
- * Copyright (c) 2001-2008 Willem Dijkstra
+ * Copyright (c) 2001-2024 Willem Dijkstra
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -67,20 +65,21 @@ read_host_port(struct muxlist * mul, struct mux * mux, struct lex * l)
 
     /* check for port statement */
     if (!lex_nexttoken(l))
-        return 1;
-
-    if (l->op == LXT_PORT || l->op == LXT_COMMA)
-        lex_nexttoken(l);
-
-    if (l->type != LXY_NUMBER) {
-        lex_ungettoken(l);
         mux->port = xstrdup(default_symux_port);
-    } else {
-        mux->port = xstrdup((const char *) l->token);
+    else {
+        if (l->op == LXT_PORT || l->op == LXT_COMMA)
+            lex_nexttoken(l);
+
+        if (l->type != LXY_NUMBER) {
+            lex_ungettoken(l);
+            mux->port = xstrdup(default_symux_port);
+        } else {
+            mux->port = xstrdup((const char *) l->token);
+        }
     }
 
     bzero(&muxname, sizeof(muxname));
-    snprintf(&muxname[0], sizeof(muxname), "%s %s", mux->addr, mux->port);
+    snprintf(&muxname[0], sizeof(muxname), "%s %s (%ds)", mux->addr, mux->port, mux->interval);
     if (rename_mux(mul, mux, muxname) == NULL) {
         warning("%.200s:%d: monitored data for host '%.200s' has already been specified",
                 l->filename, l->cline, muxname);
@@ -115,8 +114,11 @@ read_symon_args(struct mux * mux, struct lex * l)
         case LXT_PFQ:
         case LXT_PROC:
         case LXT_SENSOR:
+        case LXT_SMART:
+        case LXT_LOAD:
+        case LXT_FLUKSO:
             st = token2type(l->op);
-            strncpy(&sn[0], l->token, _POSIX2_LINE_MAX);
+            strncpy(&sn[0], l->token, (_POSIX2_LINE_MAX - 1));
 
             /* parse arg */
             lex_nexttoken(l);
@@ -126,7 +128,7 @@ read_symon_args(struct mux * mux, struct lex * l)
                     parse_error(l, "<stream argument>");
                     return 0;
                 }
-                strncpy(&sa[0], l->token, _POSIX2_LINE_MAX);
+                strncpy(&sa[0], l->token, (_POSIX2_LINE_MAX - 1));
                 lex_nexttoken(l);
                 if (l->op != LXT_CLOSE) {
                     parse_error(l, ")");
@@ -153,7 +155,7 @@ read_symon_args(struct mux * mux, struct lex * l)
         case LXT_COMMA:
             break;
         default:
-            parse_error(l, "{cpu|cpuiow|df|if|if1|io|io1|mem|mem1|pf|pfq|mbuf|debug|proc|sensor}");
+            parse_error(l, "{cpu|cpuiow|df|if|if1|io|io1|load|mem|mem1|pf|pfq|mbuf|debug|proc|sensor|smart|load|flukso}");
             return 0;
             break;
         }
@@ -182,9 +184,9 @@ read_monitor(struct muxlist * mul, struct lex * l)
         lex_nexttoken(l);
 
         if (l->op == LXT_SECOND) {
-            symon_interval = 1;
+            mux->interval = 1;
         } else if (l->type == LXY_NUMBER) {
-            symon_interval = l->value;
+            mux->interval = l->value;
             lex_nexttoken(l);
             if (l->op != LXT_SECONDS) {
                 parse_error(l, "seconds");
@@ -195,7 +197,8 @@ read_monitor(struct muxlist * mul, struct lex * l)
         }
 
         lex_nexttoken(l);
-    }
+    } else
+        mux->interval = SYMON_DEFAULT_INTERVAL;
 
     /* parse [stream [from <host>] to] */
     if (l->op != LXT_STREAM) {
@@ -260,10 +263,9 @@ read_config_file(struct muxlist *muxlist, char *filename)
                     l->filename, mux->name);
             return 0;
         }
-    }
-
-    if (symon_interval < SYMON_DEFAULT_INTERVAL) {
-        warning("%.200s: monitoring set to every %d s", l->filename, symon_interval);
+        if (mux->interval < SYMON_DEFAULT_INTERVAL) {
+            warning("%.200s: monitoring set to every %d s", l->filename, mux->interval);
+        }
     }
 
     close_lex(l);
