@@ -1,7 +1,5 @@
-/* $Id: symon.c,v 1.53 2008/02/12 12:43:04 dijkstra Exp $ */
-
 /*
- * Copyright (c) 2001-2008 Willem Dijkstra
+ * Copyright (c) 2001-2024 Willem Dijkstra
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -57,16 +55,19 @@
 
 __BEGIN_DECLS
 void alarmhandler(int);
-void drop_privileges();
 void exithandler(int);
 void huphandler(int);
-void set_stream_use(struct muxlist *);
+void init_streams(struct muxlist *mul);
+void drop_privileges(int unsecure);
 __END_DECLS
 
 int flag_unsecure = 0;
 int flag_hup = 0;
 int flag_testconf = 0;
-int symon_interval = SYMON_DEFAULT_INTERVAL;
+int symon_interval = 0;
+
+/* program wide time_t indicating start of measurement time */
+time_t now;
 
 /* map stream types to inits and getters */
 struct funcmap streamfunc[] = {
@@ -85,23 +86,48 @@ struct funcmap streamfunc[] = {
     {MT_MEM2, 0, NULL, init_mem, gets_mem, get_mem},
     {MT_IF2, 0, NULL, init_if, gets_if, get_if},
     {MT_CPUIOW, 0, NULL, init_cpuiow, gets_cpuiow, get_cpuiow},
-    {MT_EOT, 0, NULL, NULL, NULL}
+    {MT_SMART, 0, NULL, init_smart, gets_smart, get_smart},
+    {MT_LOAD, 0, NULL, init_load, gets_load, get_load},
+    {MT_FLUKSO, 0, NULL, init_flukso, gets_flukso, get_flukso},
+    {MT_EOT, 0, NULL, NULL, NULL, NULL}
 };
 
 void
-set_stream_use(struct muxlist *mul)
+init_streams(struct muxlist *mul)
 {
-    struct mux *mux;
+    struct itimerval alarminterval;
     struct stream *stream;
-    int i;
+    struct mux *mux;
 
-    for (i = 0; i < MT_EOT; i++)
-        streamfunc[i].used = 0;
+    mux = NULL;
 
+    if ((mul == NULL) || ((mux = SLIST_FIRST(mul)) == NULL))
+        fatal("empty mux list");
+
+    symon_interval = mux->interval;
 
     SLIST_FOREACH(mux, mul, muxes) {
-        SLIST_FOREACH(stream, &mux->sl, streams)
-            streamfunc[stream->type].used = 1;
+        /* determine gcd of alarm times */
+        symon_interval = gcd(symon_interval, mux->interval);
+
+        /* init network */
+        init_symon_packet(mux);
+        connect2mux(mux);
+
+        /* init modules */
+        SLIST_FOREACH(stream, &mux->sl, streams) {
+            (streamfunc[stream->type].init) (stream);
+        }
+    }
+
+    /* setup alarm */
+    timerclear(&alarminterval.it_interval);
+    timerclear(&alarminterval.it_value);
+    alarminterval.it_interval.tv_sec =
+        alarminterval.it_value.tv_sec = symon_interval;
+
+    if (setitimer(ITIMER_REAL, &alarminterval, NULL) != 0) {
+        fatal("alarm setup failed: %.200s", strerror(errno));
     }
 }
 void
@@ -173,10 +199,9 @@ int
 main(int argc, char *argv[])
 {
     struct muxlist mul, newmul;
-    struct itimerval alarminterval;
     struct stream *stream;
     struct mux *mux;
-    time_t now, last_update;
+    time_t last_update;
     FILE *pidfile;
     char *cfgpath;
     int ch;
@@ -211,6 +236,7 @@ main(int argc, char *argv[])
 
         case 'v':
             info("symon version %s", SYMON_VERSION);
+            /* FALLTHROUGH */
         default:
             info("usage: %s [-d] [-t] [-u] [-v] [-f cfgfile]", __progname);
             exit(EX_USAGE);
@@ -225,7 +251,11 @@ main(int argc, char *argv[])
         exit(EX_OK);
     }
 
-    set_stream_use(&mul);
+    SLIST_FOREACH(mux, &mul, muxes) {
+        SLIST_FOREACH(stream, &mux->sl, streams) {
+            streamfunc[stream->type].used = 1;
+        }
+    }
 
     /* open resources that might not be available after privilege drop */
     for (i = 0; i < MT_EOT; i++)
@@ -268,24 +298,7 @@ main(int argc, char *argv[])
     /* prepare crc32 */
     init_crc32();
 
-    /* init modules */
-    SLIST_FOREACH(mux, &mul, muxes) {
-        init_symon_packet(mux);
-        connect2mux(mux);
-        SLIST_FOREACH(stream, &mux->sl, streams) {
-            (streamfunc[stream->type].init) (stream);
-        }
-    }
-
-    /* setup alarm */
-    timerclear(&alarminterval.it_interval);
-    timerclear(&alarminterval.it_value);
-    alarminterval.it_interval.tv_sec =
-        alarminterval.it_value.tv_sec = symon_interval;
-
-    if (setitimer(ITIMER_REAL, &alarminterval, NULL) != 0) {
-        fatal("alarm setup failed: %.200s", strerror(errno));
-    }
+    init_streams(&mul);
 
     last_update = time(NULL);
     for (;;) {                  /* FOREVER */
@@ -307,14 +320,7 @@ main(int argc, char *argv[])
                     info("read configuration file '%.200s' successfully", cfgpath);
 
                     /* init modules */
-                    SLIST_FOREACH(mux, &mul, muxes) {
-                        init_symon_packet(mux);
-                        connect2mux(mux);
-                        SLIST_FOREACH(stream, &mux->sl, streams) {
-                            (streamfunc[stream->type].init) (stream);
-                        }
-                    }
-                    set_stream_use(&mul);
+                    init_streams(&mul);
                 }
             } else {
                 info("configuration unreachable because of privsep; keeping old configuration");
@@ -331,20 +337,36 @@ main(int argc, char *argv[])
             }
             last_update = now;
 
-            /* populate for modules that get all their measurements in one go */
+            /* populate for modules that get all their measurements in one
+             * go. we bunch up calls together to ensure that the measurements
+             * happen "at the same time" */
             for (i = 0; i < MT_EOT; i++)
-                if (streamfunc[i].used && (streamfunc[i].gets != NULL))
-                    (streamfunc[i].gets) ();
+                streamfunc[i].used = 0;
+            SLIST_FOREACH(mux, &mul, muxes) {
+                mux->last += symon_interval;
+                if (mux->last >= mux->interval) {
+                    SLIST_FOREACH(stream, &mux->sl, streams) {
+                        if (streamfunc[stream->type].used == 0) {
+                            streamfunc[stream->type].used = 1;
+                            if (streamfunc[stream->type].gets != NULL)
+                                (streamfunc[stream->type].gets)();
+                        }
+                    }
+                }
+            }
 
             SLIST_FOREACH(mux, &mul, muxes) {
-                prepare_packet(mux);
+                if (mux->last >= mux->interval) {
+                    mux->last = 0;
+                    prepare_packet(mux, now);
 
-                SLIST_FOREACH(stream, &mux->sl, streams)
-                    stream_in_packet(stream, mux);
+                    SLIST_FOREACH(stream, &mux->sl, streams)
+                        stream_in_packet(stream, mux);
 
-                finish_packet(mux);
+                    finish_packet(mux);
 
-                send_packet(mux);
+                    send_packet(mux);
+                }
             }
         }
     }
