@@ -1,7 +1,5 @@
-/* $Id: readconf.c,v 1.35 2008/01/30 12:06:50 dijkstra Exp $ */
-
 /*
- * Copyright (c) 2001-2008 Willem Dijkstra
+ * Copyright (c) 2001-2024 Willem Dijkstra
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -55,7 +53,8 @@ const char *default_symux_port = SYMUX_PORT;
 int
 insert_filename(char *path, int maxlen, int type, char *args)
 {
-    int i, result;
+    size_t i;
+    int result;
     char *ts;
     char *ta;
     char *fta;
@@ -117,6 +116,19 @@ insert_filename(char *path, int maxlen, int type, char *args)
         ts = "sensor_";
         ta = args;
         break;
+    case MT_SMART:
+        ts = "smart_";
+        ta = args;
+        break;
+    case MT_LOAD:
+        ts = "load";
+        ta = "";
+        break;
+    case MT_FLUKSO:
+        ts = "flukso_";
+        ta = args;
+        break;
+
     default:
         warning("%.200s:%d: internal error: type (%d) unknown",
                 __FILE__, __LINE__, type);
@@ -230,8 +242,11 @@ read_source(struct sourcelist * sol, struct lex * l, int filecheck)
                 case LXT_PFQ:
                 case LXT_PROC:
                 case LXT_SENSOR:
+                case LXT_SMART:
+                case LXT_LOAD:
+                case LXT_FLUKSO:
                     st = token2type(l->op);
-                    strncpy(&sn[0], l->token, _POSIX2_LINE_MAX);
+                    strncpy(&sn[0], l->token, (_POSIX2_LINE_MAX - 1));
 
                     /* parse arg */
                     lex_nexttoken(l);
@@ -242,7 +257,7 @@ read_source(struct sourcelist * sol, struct lex * l, int filecheck)
                             return 0;
                         }
 
-                        strncpy(&sa[0], l->token, _POSIX2_LINE_MAX);
+                        strncpy(&sa[0], l->token, (_POSIX2_LINE_MAX - 1));
                         lex_nexttoken(l);
 
                         if (l->op != LXT_CLOSE) {
@@ -271,7 +286,7 @@ read_source(struct sourcelist * sol, struct lex * l, int filecheck)
                 case LXT_COMMA:
                     break;
                 default:
-                    parse_error(l, "{cpu|mem|if|io|pf|debug|mbuf|proc|sensor}");
+                    parse_error(l, "{cpu|cpuiow|df|if|if1|io|io1|mem|mem1|pf|pfq|mbuf|debug|proc|sensor|smart|load|flukso}");
                     return 0;
 
                     break;
@@ -305,7 +320,7 @@ read_source(struct sourcelist * sol, struct lex * l, int filecheck)
                 }
             }
 
-            strncpy(&path[0], l->token, _POSIX2_LINE_MAX);
+            strncpy(&path[0], l->token, (_POSIX2_LINE_MAX - 1));
             path[_POSIX2_LINE_MAX - 1] = '\0';
 
             pc = strlen(path);
@@ -373,8 +388,11 @@ read_source(struct sourcelist * sol, struct lex * l, int filecheck)
             case LXT_PFQ:
             case LXT_PROC:
             case LXT_SENSOR:
+            case LXT_SMART:
+            case LXT_LOAD:
+            case LXT_FLUKSO:
                 st = token2type(l->op);
-                strncpy(&sn[0], l->token, _POSIX2_LINE_MAX);
+                strncpy(&sn[0], l->token, (_POSIX2_LINE_MAX - 1));
 
                 /* parse arg */
                 lex_nexttoken(l);
@@ -385,7 +403,7 @@ read_source(struct sourcelist * sol, struct lex * l, int filecheck)
                         return 0;
                     }
 
-                    strncpy(&sa[0], l->token, _POSIX2_LINE_MAX);
+                    strncpy(&sa[0], l->token, (_POSIX2_LINE_MAX - 1));
                     lex_nexttoken(l);
                     if (l->op != LXT_CLOSE) {
                         parse_error(l, ")");
@@ -434,7 +452,7 @@ read_source(struct sourcelist * sol, struct lex * l, int filecheck)
                 }
                 break;          /* LXT_resource */
             default:
-                parse_error(l, "{cpu|cpuiow|df|if|if1|io|io1|mem|mem1|pf|pfq|mbuf|debug|proc|sensor}");
+                parse_error(l, "{cpu|cpuiow|df|if|if1|io|io1|mem|mem1|pf|pfq|mbuf|debug|proc|sensor|smart|load|flukso}");
                 return 0;
                 break;
             }
