@@ -1,7 +1,5 @@
-/* $Id: share.c,v 1.21 2007/02/11 20:07:32 dijkstra Exp $ */
-
 /*
- * Copyright (c) 2001-2005 Willem Dijkstra
+ * Copyright (c) 2001-2024 Willem Dijkstra
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -30,6 +28,8 @@
  *
  */
 
+#include "conf.h"
+
 /* Share contains all routines needed for the ipc between symuxes */
 #include <sys/types.h>
 #include <sys/ipc.h>
@@ -46,7 +46,6 @@
 #include <sysexits.h>
 #include <unistd.h>
 
-#include "conf.h"
 #include "data.h"
 #include "error.h"
 #include "symux.h"
@@ -78,15 +77,15 @@
  */
 
 __BEGIN_DECLS
-void check_master();
-void check_sem();
-void client_doneread();
-void client_loop();
-void client_signalhandler();
-int client_waitread();
-void exitmaster();
+void check_master(void);
+void check_sem(void);
+void client_doneread(void);
+void client_loop(void);
+void client_signalhandler(int);
+int client_waitread(void);
+void exitmaster(void);
 void master_resetsem(int);
-void reap_clients();
+void reap_clients(void);
 __END_DECLS
 
 int realclients;                /* number of clients active */
@@ -115,7 +114,7 @@ shared_getmem(int slot)
 }
 /* Get max length of data stored in shared region */
 long
-shared_getmaxlen()
+shared_getmaxlen(void)
 {
     return shm->slotlen;
 }
@@ -138,7 +137,7 @@ shared_getlen(int slot)
 }
 /* Check whether semaphore is available */
 void
-check_sem()
+check_sem(void)
 {
     if (semstat != SIPC_KEYED)
         fatal("%s:%d: internal error: semaphore not available",
@@ -147,7 +146,7 @@ check_sem()
 
 /* Check whether process is the master process */
 void
-check_master()
+check_master(void)
 {
     if (master == 0)
         fatal("%s:%d: internal error: child process tried to access master routines",
@@ -171,7 +170,7 @@ master_resetsem(int semnum)
 }
 /* Prepare for writing to shm */
 int
-master_forbidread()
+master_forbidread(void)
 {
     int slot = (shm->seqnr + 1) % SYMUX_SHARESLOTS;
     int stalledclients;
@@ -199,7 +198,7 @@ master_forbidread()
 }
 /* Signal 'permit read' to all clients */
 void
-master_permitread()
+master_permitread(void)
 {
     int slot = ++shm->seqnr % SYMUX_SHARESLOTS;
     union semun semarg;
@@ -212,7 +211,7 @@ master_permitread()
 }
 /* Make clients wait until master signals */
 int
-client_waitread()
+client_waitread(void)
 {
     int slot = ++seqnr % SYMUX_SHARESLOTS;
     struct sembuf sops;
@@ -237,7 +236,7 @@ client_waitread()
 }
 /* Client signal 'done reading' to master */
 void
-client_doneread()
+client_doneread(void)
 {
     /* force scheduling by sleeping a single second */
     sleep(1);
@@ -339,7 +338,7 @@ spawn_client(int sock)
 }
 /* Reap exit/stopped clients */
 void
-reap_clients()
+reap_clients(void)
 {
     pid_t pid;
     int status;
@@ -366,7 +365,7 @@ reap_clients()
 }
 /* Remove shared memory and semaphores at exit */
 void
-exitmaster()
+exitmaster(void)
 {
     union semun semarg;
 
@@ -379,12 +378,12 @@ exitmaster()
             warning("%s:%d: internal error: control region could not be detached",
                     __FILE__, __LINE__);
 
-        /* no break */
+        /* FALLTHROUGH */
     case SIPC_KEYED:
         if (shmctl(shmid, IPC_RMID, NULL))
             warning("%s:%d: internal error: could remove control region %d",
                     __FILE__, __LINE__, shmid);
-        /* no break */
+        /* FALLTHROUGH */
     case SIPC_FREE:
         break;
 
@@ -399,7 +398,7 @@ exitmaster()
         if (semctl(semid, 0, IPC_RMID, semarg) != 0)
             warning("%s:%d: internal error: could not remove semaphore %d",
                     __FILE__, __LINE__, semid);
-        /* no break */
+        /* FALLTHROUGH */
     case SIPC_FREE:
         break;
 
@@ -409,7 +408,7 @@ exitmaster()
     }
 }
 void
-client_loop()
+client_loop(void)
 {
     int slot;
     int total;
