@@ -1,7 +1,5 @@
-/* $Id: share.h,v 1.10 2007/02/11 20:07:32 dijkstra Exp $ */
-
 /*
- * Copyright (c) 2001-2004 Willem Dijkstra
+ * Copyright (c) 2001-2024 Willem Dijkstra
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -50,12 +48,12 @@ struct sharedregion {
 
 /* prototypes */
 __BEGIN_DECLS
-int master_forbidread();
-void master_permitread();
+int master_forbidread(void);
+void master_permitread(void);
 long shared_getlen(int);
-long shared_getmaxlen();
+long shared_getmaxlen(void);
 char *shared_getmem(int);
-void initshare();
+void initshare(int);
 void shared_setlen(int, long);
 pid_t spawn_client(int);
 __END_DECLS
