@@ -1,7 +1,5 @@
-/* $Id: symux.c,v 1.41 2007/11/29 13:55:30 dijkstra Exp $ */
-
 /*
- * Copyright (c) 2001-2007 Willem Dijkstra
+ * Copyright (c) 2001-2024 Willem Dijkstra
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -56,8 +54,10 @@
 #include "share.h"
 #include "xmalloc.h"
 
+#include "platform.h"
+
 __BEGIN_DECLS
-void exithandler();
+void exithandler(int);
 void huphandler(int);
 void signalhandler(int);
 __END_DECLS
@@ -105,7 +105,7 @@ main(int argc, char *argv[])
     char *stringptr;
     int maxstringlen;
     struct muxlist mul, newmul;
-    char *arg_ra[4];
+    const char *arg_ra[4];
     struct stream *stream;
     struct source *source;
     struct sourcelist *sol;
@@ -138,8 +138,8 @@ main(int argc, char *argv[])
         case 'f':
             if (optarg && optarg[0] != '/') {
                 /* cfg path needs to be absolute, we will be a daemon soon */
-                cfgpath = xmalloc(MAXPATHLEN);
-                if ((cfgpath = getcwd(cfgpath, MAXPATHLEN)) == NULL)
+                cfgpath = xmalloc(MAX_PATH_LEN);
+                if ((cfgpath = getcwd(cfgpath, MAX_PATH_LEN)) == NULL)
                     fatal("could not get working directory");
 
                 maxstringlen = strlen(cfgpath) + 1 + strlen(optarg) + 1;
@@ -166,6 +166,7 @@ main(int argc, char *argv[])
 
         case 'v':
             info("symux version %s", SYMUX_VERSION);
+            /* FALLTHROUGH */
         default:
             info("usage: %s [-d] [-l] [-v] [-f cfgfile]", __progname);
             exit(EX_USAGE);
@@ -370,7 +371,7 @@ main(int argc, char *argv[])
                     stringptr += strlen(stringptr);
                 } else {
                     debug("ignored unaccepted stream %.16s(%.16s) from %.20s", type2str(ps.type),
-                          ((ps.arg == NULL) ? "0" : ps.arg), source->addr);
+                          ((strlen(ps.arg) == 0) ? "0" : ps.arg), source->addr);
                 }
             }
             /*
